@@ -2,7 +2,7 @@ c Wrapper for Lapack's dggsvd
 
       subroutine xdggsvd(kjobu, kjobv, kjobq, m, n, p, k, l, a, lda, b,
      *                   ldb, alpha, beta, u, ldu, v, ldv, q, ldq,
-     *                   work, iwork, info)
+     *                   work, lwork, iwork, info)
 c
 c  -- lapack driver routine (version 3.4.0) --
 c  -- lapack is a software package provided by univ. of tennessee,    --
@@ -12,6 +12,7 @@ c
 c     .. scalar arguments ..
       integer            kjobu, kjobv, kjobq
       integer            info, k, l, lda, ldb, ldq, ldu, ldv, m, n, p
+      integer lwork
 c     ..
 c     .. array arguments ..
       integer            iwork(*)
@@ -30,9 +31,9 @@ c     select job parameters
 c     jobu = 'U'
 c     jobv = 'V'
 c     jobq = 'Q'
-      call dggsvd(jobu, jobv, jobq, m, n, p, k, l, A, lda, B, ldb,
-     *            alpha, beta, u, ldu, v, ldv, q, ldq,
-     *            work, iwork, info)
+      call dggsvd3(jobu, jobv, jobq, m, n, p, k, l, A, lda, B, ldb,
+     *             alpha, beta, u, ldu, v, ldv, q, ldq,
+     *             work, lwork, iwork, info)
 
       return
       end
