@@ -14,10 +14,14 @@ c     .. Array Arguments ..
      *                   beta(*), vl(ldvl, *), vr(ldvr, *),
      *                   work(*)
 
+      character*2        cjobv
+      parameter(cjobv='NV')
       character          jobvl, jobvr
 
-      jobvl = 'NV'(kjobvl:kjobvl)
-      jobvr = 'NV'(kjobvr:kjobvr)
+c     if you change the cxxx values don't forget to adjust the R functions
+
+      jobvl = cjobv(kjobvl:kjobvl)
+      jobvr = cjobv(kjobvr:kjobvr)
 
       call zggev(jobvl, jobvr, n, a, n, b, n, alpha, beta,
      *           vl, ldvl, vr, ldvr, work, lwork, rwork, info )
@@ -36,10 +40,14 @@ c     .. Array Arguments ..
       double precision   rwork(*), w(*)
       complex*16         a(n, *), b(n, *), work(*)
       
+      character*2        cjobz, cjobul
+      parameter(cjobz='NV', cjobul='UL')
       character          jobz, uplo
 
-      jobz = 'NV'(kjobz:kjobz)
-      uplo = 'UL'(kuplo:kuplo)
+c     if you change the cxxx values don't forget to adjust the R functions
+
+      jobz = cjobz(kjobz:kjobz)
+      uplo = cjobul(kuplo:kuplo)
 
       call zhegv(itype, jobz, uplo, n, a, n, b, n, w, work,
      *           lwork, rwork, info )
